@@ -1,8 +1,8 @@
 """
-AXXE-L Workbench
+JupyterLab Workbench
 """
 
 
-__version__ = '0.1.0'
+__version__ = '0.1.3'
 __author__ = 'Ray Marc Marcellones'
 __credits__ = 'XTREME-D Inc.'
